aboutsummaryrefslogtreecommitdiff
path: root/ci
diff options
context:
space:
mode:
authorAnthony Towns <aj@erisian.com.au>2020-07-13 14:25:47 +1000
committerAnthony Towns <aj@erisian.com.au>2020-11-09 17:53:47 +1000
commit8ae9d314e9af7bcce1e8bc52f0317b9d565109bf (patch)
treeb8c1b61825f1cdfb31b523e02c8b08dc4b8489f3 /ci
parent7e373294a5ae819099c39d9d03d1f5a311d63cfc (diff)
downloadbitcoin-8ae9d314e9af7bcce1e8bc52f0317b9d565109bf.tar.xz
Bump minimum python version to 3.6
Diffstat (limited to 'ci')
-rw-r--r--ci/test/00_setup_env_native_nowallet.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/ci/test/00_setup_env_native_nowallet.sh b/ci/test/00_setup_env_native_nowallet.sh
index 0a09bfe230..0fe7d35435 100644
--- a/ci/test/00_setup_env_native_nowallet.sh
+++ b/ci/test/00_setup_env_native_nowallet.sh
@@ -7,8 +7,8 @@
export LC_ALL=C.UTF-8
export CONTAINER_NAME=ci_native_nowallet
-export DOCKER_NAME_TAG=ubuntu:16.04 # Use xenial to have one config run the tests in python3.5, see doc/dependencies.md
-export PACKAGES="python3-zmq clang-3.8 llvm-3.8" # Use clang-3.8 to test C++11 compatibility, see doc/dependencies.md
+export DOCKER_NAME_TAG=ubuntu:18.04 # Use bionic to have one config run the tests in python3.6, see doc/dependencies.md (3.6 is not available in xenial/16.04)
+export PACKAGES="python3-zmq clang-3.9 llvm-3.9" # Use clang-3.9 to test C++11 compatibility, see doc/dependencies.md (3.8 is not available in bionic)
export DEP_OPTS="NO_WALLET=1"
export GOAL="install"
-export BITCOIN_CONFIG="--enable-glibc-back-compat --enable-reduce-exports CC=clang-3.8 CXX=clang++-3.8 --with-boost-process"
+export BITCOIN_CONFIG="--enable-glibc-back-compat --enable-reduce-exports CC=clang-3.9 CXX=clang++-3.9 --with-boost-process"